@@ -9,12 +9,13 @@ import numpy as np
 import vtk
 
 import pyvista
+from pyvista.core.errors import DeprecationError
 
 # Helpers:
 
 def _check_examples_path():
     """Check if the examples path exists."""
-    if pyvista.EXAMPLES_PATH is None:
+    if not pyvista.EXAMPLES_PATH:
         raise FileNotFoundError('EXAMPLES_PATH does not exist.  Try setting the '
                                 'environment variable `PYVISTA_USERDATA_PATH` '
                                 'to a writable path and restarting python')
@@ -65,10 +66,12 @@ def _retrieve_file(url, filename):
         local_path = local_path[:-4]
     return local_path, resp
 
+
 def _download_file(filename):
     url = _get_vtk_file_url(filename)
     return _retrieve_file(url, filename)
 
+
 def _download_and_read(filename, texture=False, file_format=None):
     saved_file, _ = _download_file(filename)
     if texture:
@@ -82,55 +85,68 @@ def download_masonry_texture():
     """Download masonry texture."""
     return _download_and_read('masonry.bmp', texture=True)
 
+
 def download_usa_texture():
     """Download usa texture."""
     return _download_and_read('usa_image.jpg', texture=True)
 
+
 def download_puppy_texture():
     """Download puppy texture."""
     return _download_and_read('puppy.jpg', texture=True)
 
+
 def download_puppy():
     """Download puppy dataset."""
     return _download_and_read('puppy.jpg')
 
+
 def download_usa():
     """Download usa dataset."""
     return _download_and_read('usa.vtk')
 
+
 def download_st_helens():
     """Download Saint Helens dataset."""
     return _download_and_read('SainteHelens.dem')
 
+
 def download_bunny():
     """Download bunny dataset."""
     return _download_and_read('bunny.ply')
 
+
 def download_bunny_coarse():
     """Download coarse bunny dataset."""
     return _download_and_read('Bunny.vtp')
 
+
 def download_cow():
     """Download cow dataset."""
     return _download_and_read('cow.vtp')
 
+
 def download_cow_head():
     """Download cow head dataset."""
     return _download_and_read('cowHead.vtp')
 
+
 def download_faults():
     """Download faults dataset."""
     return _download_and_read('faults.vtk')
 
+
 def download_tensors():
     """Download tensors dataset."""
     return _download_and_read('tensors.vtk')
 
+
 def download_head():
     """Download head dataset."""
     _download_file('HeadMRVolume.raw')
     return _download_and_read('HeadMRVolume.mhd')
 
+
 def download_bolt_nut():
     """Download bolt nut dataset."""
     blocks = pyvista.MultiBlock()
@@ -138,42 +154,52 @@ def download_bolt_nut():
     blocks['nut'] = _download_and_read('nut.slc')
     return blocks
 
+
 def download_clown():
     """Download clown dataset."""
     return _download_and_read('clown.facet')
 
+
 def download_topo_global():
     """Download topo dataset."""
     return _download_and_read('EarthModels/ETOPO_10min_Ice.vtp')
 
+
 def download_topo_land():
     """Download topo land dataset."""
     return _download_and_read('EarthModels/ETOPO_10min_Ice_only-land.vtp')
 
+
 def download_coastlines():
     """Download coastlines dataset."""
     return _download_and_read('EarthModels/Coastlines_Los_Alamos.vtp')
 
+
 def download_knee():
     """Download knee dataset."""
     return _download_and_read('DICOM_KNEE.dcm')
 
+
 def download_knee_full():
     """Download full knee dataset."""
     return _download_and_read('vw_knee.slc')
 
+
 def download_lidar():
     """Download lidar dataset."""
     return _download_and_read('kafadar-lidar-interp.vtp')
 
+
 def download_exodus():
     """Sample ExodusII data file."""
     return _download_and_read('mesh_fs8.exo')
 
+
 def download_nefertiti():
     """Download mesh of Queen Nefertiti."""
     return _download_and_read('Nefertiti.obj.zip')
 
+
 def download_blood_vessels():
     """Download data representing the bifurcation of blood vessels."""
     local_path, _ = _download_file('pvtu_blood_vessels/blood_vessels.zip')
@@ -182,18 +208,31 @@ def download_blood_vessels():
     mesh.set_active_vectors('velocity')
     return mesh
 
-def download_iron_pot():
-    """Download iron pot dataset."""
+
+def download_iron_pot():  # pragma: no cover
+    """Download iron protein dataset.
+
+    DEPRECATED: Please use ``download_iron_protein``.
+
+    """
+    raise DeprecationError('DEPRECATED: Please use ``download_iron_protein``')
+
+
+def download_iron_protein():
+    """Download iron protein dataset."""
     return _download_and_read('ironProt.vtk')
 
+
 def download_tetrahedron():
     """Download tetrahedron dataset."""
     return _download_and_read('Tetrahedron.vtu')
 
+
 def download_saddle_surface():
     """Download saddle surface dataset."""
     return _download_and_read('InterpolatingOnSTL_final.stl')
 
+
 def download_sparse_points():
     """Download sparse points dataset.
 
@@ -214,178 +253,220 @@ def download_sparse_points():
     table_points.Update()
     return pyvista.wrap(table_points.GetOutput())
 
+
 def download_foot_bones():
     """Download foot bones dataset."""
     return _download_and_read('fsu/footbones.ply')
 
+
 def download_guitar():
     """Download guitar dataset."""
     return _download_and_read('fsu/stratocaster.ply')
 
+
 def download_quadratic_pyramid():
     """Download quadratic pyramid dataset."""
     return _download_and_read('QuadraticPyramid.vtu')
 
+
 def download_bird():
     """Download bird dataset."""
     return _download_and_read('Pileated.jpg')
 
+
 def download_bird_texture():
     """Download bird texture."""
     return _download_and_read('Pileated.jpg', texture=True)
 
+
 def download_office():
     """Download office dataset."""
     return _download_and_read('office.binary.vtk')
 
+
 def download_horse_points():
     """Download horse points dataset."""
     return _download_and_read('horsePoints.vtp')
 
+
 def download_horse():
     """Download horse dataset."""
     return _download_and_read('horse.vtp')
 
+
 def download_cake_easy():
     """Download cake dataset."""
     return _download_and_read('cake_easy.jpg')
 
+
 def download_cake_easy_texture():
     """Download cake texture."""
     return _download_and_read('cake_easy.jpg', texture=True)
 
+
 def download_rectilinear_grid():
     """Download rectilinear grid dataset."""
     return _download_and_read('RectilinearGrid.vtr')
 
+
 def download_gourds(zoom=False):
     """Download gourds dataset."""
     if zoom:
         return _download_and_read('Gourds.png')
     return _download_and_read('Gourds2.jpg')
 
+
 def download_gourds_texture(zoom=False):
     """Download gourds texture."""
     if zoom:
         return _download_and_read('Gourds.png', texture=True)
     return _download_and_read('Gourds2.jpg', texture=True)
 
+
 def download_unstructured_grid():
     """Download unstructured grid dataset."""
     return _download_and_read('uGridEx.vtk')
 
+
 def download_letter_k():
     """Download letter k dataset."""
     return _download_and_read('k.vtk')
 
+
 def download_letter_a():
     """Download letter a dataset."""
     return _download_and_read('a_grid.vtk')
 
+
 def download_poly_line():
     """Download polyline dataset."""
     return _download_and_read('polyline.vtk')
 
+
 def download_cad_model():
     """Download cad dataset."""
     return _download_and_read('42400-IDGH.stl')
 
+
 def download_frog():
     """Download frog dataset."""
     # TODO: there are other files with this
     _download_file('froggy/frog.zraw')
     return _download_and_read('froggy/frog.mhd')
 
+
 def download_prostate():
     """Download prostate dataset."""
     return _download_and_read('prostate.img')
 
+
 def download_filled_contours():
     """Download filled contours dataset."""
     return _download_and_read('filledContours.vtp')
 
+
 def download_doorman():
     """Download doorman dataset."""
     # TODO: download textures as well
     return _download_and_read('doorman/doorman.obj')
 
+
 def download_mug():
     """Download mug dataset."""
     return _download_and_read('mug.e')
 
+
 def download_oblique_cone():
     """Download oblique cone dataset."""
     return _download_and_read('ObliqueCone.vtp')
 
+
 def download_emoji():
     """Download emoji dataset."""
     return _download_and_read('emote.jpg')
 
+
 def download_emoji_texture():
     """Download emoji texture."""
     return _download_and_read('emote.jpg', texture=True)
 
+
 def download_teapot():
     """Download teapot dataset."""
     return _download_and_read('teapot.g')
 
+
 def download_brain():
     """Download brain dataset."""
     return _download_and_read('brain.vtk')
 
+
 def download_structured_grid():
     """Download structured grid dataset."""
     return _download_and_read('StructuredGrid.vts')
 
+
 def download_structured_grid_two():
     """Download structured grid two dataset."""
     return _download_and_read('SampleStructGrid.vtk')
 
+
 def download_trumpet():
     """Download trumpet dataset."""
     return _download_and_read('trumpet.obj')
 
+
 def download_face():
     """Download face dataset."""
     # TODO: there is a texture with this
     return _download_and_read('fran_cut.vtk')
 
+
 def download_sky_box_nz():
     """Download skybox-nz dataset."""
     return _download_and_read('skybox-nz.jpg')
 
+
 def download_sky_box_nz_texture():
     """Download skybox-nz texture."""
     return _download_and_read('skybox-nz.jpg', texture=True)
 
+
 def download_disc_quads():
     """Download disc quads dataset."""
     return _download_and_read('Disc_BiQuadraticQuads_0_0.vtu')
 
+
 def download_honolulu():
     """Download honolulu dataset."""
     return _download_and_read('honolulu.vtk')
 
+
 def download_motor():
     """Download motor dataset."""
     return _download_and_read('motor.g')
 
+
 def download_tri_quadratic_hexahedron():
     """Download tri quadratic hexahedron dataset."""
     return _download_and_read('TriQuadraticHexahedron.vtu')
 
+
 def download_human():
     """Download human dataset."""
     return _download_and_read('Human.vtp')
 
+
 def download_vtk():
     """Download vtk dataset."""
     return _download_and_read('vtk.vtp')
 
+
 def download_spider():
     """Download spider dataset."""
     return _download_and_read('spider.ply')
 
+
 def download_carotid():
     """Download carotid dataset."""
     mesh = _download_and_read('carotid.vtk')
@@ -393,30 +474,37 @@ def download_carotid():
     mesh.set_active_vectors('vectors')
     return mesh
 
+
 def download_blow():
     """Download blow dataset."""
     return _download_and_read('blow.vtk')
 
+
 def download_shark():
     """Download shark dataset."""
     return _download_and_read('shark.ply')
 
+
 def download_dragon():
     """Download dragon dataset."""
     return _download_and_read('dragon.ply')
 
+
 def download_armadillo():
     """Download armadillo dataset."""
     return _download_and_read('Armadillo.ply')
 
+
 def download_gears():
     """Download gears dataset."""
     return _download_and_read('gears.stl')
 
+
 def download_torso():
     """Download torso dataset."""
     return _download_and_read('Torso.vtp')
 
+
 def download_kitchen(split=False):
     """Download structured grid of kitchen with velocity field.
 
@@ -479,7 +567,7 @@ def download_model_with_variance():
 
 
 def download_thermal_probes():
-    """Download model with variance dataset."""
+    """Download thermal probes dataset."""
     return _download_and_read("probes.vtp")
 
 
@@ -539,7 +627,7 @@ def download_urn():
 
 
 def download_pepper():
-    """Download scan of a burial urn.
+    """Download scan of a pepper (capsicum).
 
     https://www.laserdesign.com/sample-files/hot-red-pepper/
 
@@ -560,7 +648,6 @@ def download_drill():
     return pyvista.read(filename)
 
 
-
 def download_action_figure():
     """Download scan of an action figure.
 
@@ -599,7 +686,7 @@ def download_crater_imagery():
 
 
 def download_dolfin():
-    """Download crater texture."""
+    """Download dolfin mesh."""
     return _download_and_read('dolfin_fine.xml', file_format="dolfin-xml")
 
 
@@ -650,20 +737,22 @@ def download_vtk_logo():
     """Download a texture of the VTK logo."""
     return _download_and_read("vtk.png", texture=True)
 
+
 def download_backward_facing_step():
-    """Download an ensigh gold case of a fluid simulation."""
+    """Download an ensight gold case of a fluid simulation."""
     folder, _ = _download_file('EnSight.zip')
     filename = os.path.join(folder, "foam_case_0_0_0_0.case")
     return pyvista.read(filename)
 
+
 def download_gpr_data_array():
-    """Download a texture of the VTK logo."""
+    """Download GPR example data array."""
     saved_file, _ = _download_file("gpr-example/data.npy")
     return np.load(saved_file)
 
+
 def download_gpr_path():
-    """Download a texture of the VTK logo."""
+    """Download GPR example path."""
     saved_file, _ = _download_file("gpr-example/path.txt")
     path = np.loadtxt(saved_file, skiprows=1)
     return pyvista.PolyData(path)
-
