@@ -17,6 +17,7 @@ import vtk.util.numpy_support as nps
 
 import pyvista
 from .fileio import from_meshio
+from . import transformations
 
 
 class FieldAssociation(enum.Enum):
@@ -33,8 +34,8 @@ def get_vtk_type(typ):
 
     Corrects for string type mapping issues.
 
-    Return
-    ------
+    Returns
+    -------
         int : the integer type id specified in vtkType.h
 
     """
@@ -93,8 +94,8 @@ def convert_array(arr, name=None, deep=0, array_type=None):
     deep : bool
         if input is numpy array then deep copy values
 
-    Return
-    ------
+    Returns
+    -------
     vtkDataArray, ndarray, or DataFrame:
         the converted array (if input is a NumPy ndaray then returns
         ``vtkDataArray`` or is input is ``vtkDataArray`` then returns NumPy
@@ -319,8 +320,8 @@ def lines_from_points(points, close=False):
     close : bool, optional
         If True, close the line segments into a loop
 
-    Return
-    ------
+    Returns
+    -------
     lines : pyvista.PolyData
         PolyData with lines and cells.
 
@@ -336,6 +337,55 @@ def lines_from_points(points, close=False):
     return poly
 
 
+def make_tri_mesh(points, faces):
+    """Construct a ``pyvista.PolyData`` mesh using points and faces arrays.
+
+    Construct a mesh from an Nx3 array of points and an Mx3 array of
+    triangle indices, resulting in a mesh with N vertices and M
+    triangles.  This function does not require the standard VTK
+    "padding" column and simplifies mesh creation.
+
+    Parameters
+    ----------
+    points : np.ndarray
+        Array of points with shape (N, 3) storing the vertices of the
+        triangle mesh.
+
+    faces : np.ndarray
+        Array of indices with shape (M, 3) containing the triangle
+        indices.
+
+    Returns
+    -------
+    tri_mesh : pyvista.PolyData
+        PolyData instance containing the triangle mesh.
+
+    Examples
+    --------
+    This example discretizes the unit square into a triangle mesh with
+    nine vertices and eight faces.
+
+    >>> import numpy as np
+    >>> import pyvista as pv
+    >>> points = np.array([[0, 0, 0], [0.5, 0, 0], [1, 0, 0], [0, 0.5, 0],
+    ...                    [0.5, 0.5, 0], [1, 0.5, 0], [0, 1, 0], [0.5, 1, 0],
+    ...                    [1, 1, 0]])
+    >>> faces = np.array([[0, 1, 4], [4, 7, 6], [2, 5, 4], [4, 5, 8],
+    ...                   [0, 4, 3], [3, 4, 6], [1, 2, 4], [4, 8, 7]])
+    >>> tri_mesh = pyvista.make_tri_mesh(points, faces)
+    >>> tri_mesh.plot(show_edges=True) # doctest:+SKIP
+
+    """
+    if points.shape[1] != 3:
+        raise ValueError("Points array should have shape (N, 3).")
+    if faces.ndim != 2 or faces.shape[1] != 3:
+        raise ValueError("Face array should have shape (M, 3).")
+    cells = np.empty((faces.shape[0], 4), dtype=faces.dtype)
+    cells[:, 0] = 3
+    cells[:, 1:] = faces
+    return pyvista.PolyData(points, cells)
+
+
 def vector_poly_data(orig, vec):
     """Create a vtkPolyData object composed of vectors."""
     # shape, dimension checking
@@ -388,13 +438,64 @@ def vector_poly_data(orig, vec):
     return pyvista.PolyData(pdata)
 
 
-def trans_from_matrix(matrix):
-    """Convert a vtk matrix to a numpy.ndarray."""
-    t = np.zeros((4, 4))
-    for i in range(4):
-        for j in range(4):
-            t[i, j] = matrix.GetElement(i, j)
-    return t
+def trans_from_matrix(matrix):  # pragma: no cover
+    """Convert a vtk matrix to a numpy.ndarray.
+
+    DEPRECATED: Please use ``array_from_vtkmatrix``.
+
+    """
+    # import needs to happen here to prevent a circular import
+    from pyvista.core.errors import DeprecationError
+    raise DeprecationError('DEPRECATED: Please use ``array_from_vtkmatrix``.')
+
+
+def array_from_vtkmatrix(matrix):
+    """Convert a vtk matrix to a ``numpy.ndarray``.
+
+    Parameters
+    ----------
+    matrix : vtk.vtkMatrix3x3 or vtk.vtkMatrix4x4
+        The vtk matrix to be converted to a ``numpy.ndarray``.
+        Returned ndarray has shape (3, 3) or (4, 4) as appropriate.
+
+    """
+    if isinstance(matrix, vtk.vtkMatrix3x3):
+        shape = (3, 3)
+    elif isinstance(matrix, vtk.vtkMatrix4x4):
+        shape = (4, 4)
+    else:
+        raise TypeError('Expected vtk.vtkMatrix3x3 or vtk.vtkMatrix4x4 input,'
+                        f' got {type(matrix).__name__} instead.')
+    array = np.zeros(shape)
+    for i in range(shape[0]):
+        for j in range(shape[1]):
+            array[i, j] = matrix.GetElement(i, j)
+    return array
+
+
+def vtkmatrix_from_array(array):
+    """Convert a ``numpy.ndarray`` or array-like to a vtk matrix.
+
+    Parameters
+    ----------
+    array : numpy.ndarray or array-like
+        The array or array-like to be converted to a vtk matrix.
+        Shape (3, 3) gets converted to a ``vtk.vtkMatrix3x3``, shape (4, 4)
+        gets converted to a ``vtk.vtkMatrix4x4``. No other shapes are valid.
+
+    """
+    array = np.asarray(array)
+    if array.shape == (3, 3):
+        matrix = vtk.vtkMatrix3x3()
+    elif array.shape == (4, 4):
+        matrix = vtk.vtkMatrix4x4()
+    else:
+        raise ValueError(f'Invalid shape {array.shape}, must be (3, 3) or (4, 4).')
+    m, n = array.shape
+    for i in range(m):
+        for j in range(n):
+            matrix.SetElement(i, j, array[i, j])
+    return matrix
 
 
 def is_meshio_mesh(mesh):
@@ -412,7 +513,7 @@ def wrap(dataset):
     Other formats that are supported include:
     * 2D :class:`numpy.ndarray` of XYZ vertices
     * 3D :class:`numpy.ndarray` representing a volume. Values will be scalars.
-    * 3d :class:`trimesh.Trimesh` mesh.
+    * 3D :class:`trimesh.Trimesh` mesh.
 
     Parameters
     ----------
@@ -749,7 +850,7 @@ def abstract_class(cls_):
     """Decorate a class, overriding __new__.
 
     Preventing a class from being instantiated similar to abc.ABCMeta
-      but does not require an abstract method.
+    but does not require an abstract method.
     """
 
     def __new__(cls, *args, **kwargs):
@@ -761,34 +862,54 @@ def abstract_class(cls_):
 
 
 def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
-    """Rotate points angle (in deg) about an axis."""
+    """Rotate points angle (in deg) about an axis.
+
+    Parameters
+    ----------
+    points : numpy.ndarray
+        Array of points with shape ``(N, 3)``
+
+    angle : float
+        Rotation angle.
+
+    inplace : bool, optional
+        Updates points in-place while returning nothing.
+
+    deg : bool, optional
+        If `True`, the angle is interpreted as degrees instead of
+        radians. Default is `True`.
+
+    axis : str, optional
+        Name of axis to rotate about. Valid options are ``'x'``, ``'y'``,
+        and ``'z'``. Default value is ``'z'``.
+
+    Returns
+    -------
+    points : numpy.ndarray
+        Rotated points.
+
+    Examples
+    --------
+    Rotate a set of points by 90 degrees about the x-axis in-place.
+    >>> import numpy as np
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> points = examples.load_airplane().points
+    >>> points_orig = points.copy()
+    >>> pyvista.axis_rotation(points, 90, axis='x', deg=True, inplace=True)
+    >>> assert np.all(np.isclose(points[:, 0], points_orig[:, 0]))
+    >>> assert np.all(np.isclose(points[:, 1], -points_orig[:, 2]))
+    >>> assert np.all(np.isclose(points[:, 2], points_orig[:, 1]))
+    """
     axis = axis.lower()
+    axis_to_vec = {
+        'x': (1, 0, 0),
+        'y': (0, 1, 0),
+        'z': (0, 0, 1)
+    }
 
-    # Copy original array to if not inplace
-    if not inplace:
-        points = points.copy()
+    if axis not in axis_to_vec:
+        raise ValueError('Invalid axis. Must be either "x", "y", or "z"')
 
-    # Convert angle to radians
-    if deg:
-        angle *= np.pi / 180
-
-    if axis == 'x':
-        y = points[:, 1] * np.cos(angle) - points[:, 2] * np.sin(angle)
-        z = points[:, 1] * np.sin(angle) + points[:, 2] * np.cos(angle)
-        points[:, 1] = y
-        points[:, 2] = z
-    elif axis == 'y':
-        x = points[:, 0] * np.cos(angle) + points[:, 2] * np.sin(angle)
-        z = - points[:, 0] * np.sin(angle) + points[:, 2] * np.cos(angle)
-        points[:, 0] = x
-        points[:, 2] = z
-    elif axis == 'z':
-        x = points[:, 0] * np.cos(angle) - points[:, 1] * np.sin(angle)
-        y = points[:, 0] * np.sin(angle) + points[:, 1] * np.cos(angle)
-        points[:, 0] = x
-        points[:, 1] = y
-    else:
-        raise ValueError('invalid axis. Must be either "x", "y", or "z"')
-
-    if not inplace:
-        return points
+    rot_mat = transformations.axis_angle_rotation(axis_to_vec[axis], angle, deg=deg)
+    return transformations.apply_transformation_to_points(rot_mat, points, inplace=inplace)
