@@ -3,6 +3,17 @@ import vtk
 from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy
 import numpy as np
 
+import pyvista
+
+
+def remove_alpha(img):
+    """Remove the alpha channel from ``vtk.vtkImageData``."""
+    ec = vtk.vtkImageExtractComponents()
+    ec.SetComponents(0, 1, 2)
+    ec.SetInputData(img)
+    ec.Update()
+    return pyvista.wrap(ec.GetOutput())
+
 
 def wrap_image_array(arr):
     """Wrap a numpy array as a pyvista.UniformGrid.
@@ -21,10 +32,9 @@ def wrap_image_array(arr):
     if arr.dtype != np.uint8:
         raise ValueError('Expecting a np.uint8 array')
 
-    from pyvista import wrap
     img = vtk.vtkImageData()
     img.SetDimensions(arr.shape[1], arr.shape[0], 1)
-    wrap_img = wrap(img)
+    wrap_img = pyvista.wrap(img)
     wrap_img.point_arrays['PNGImage'] = arr[::-1].reshape(-1, arr.shape[2])
     return wrap_img
 
@@ -42,14 +52,6 @@ def image_from_window(ren_win, as_vtk=False, ignore_alpha=False):
     return data
 
 
-# def compare_plotters(pl1, pl2):
-#     img_diff = vtk.vtkImageDifference()
-#     img_diff.SetInputData(image_from_window(pl1, ignore_alpha=True))
-#     img_diff.SetImageData(image_from_window(pl2, ignore_alpha=True))
-#     img_diff.Update()
-#     return img_diff.GetError()
-
-
 def compare_images(im1, im2, threshold=1, use_vtk=True):
     """Compare two different images of the same size.
 
@@ -120,8 +122,11 @@ def compare_images(im1, im2, threshold=1, use_vtk=True):
             raise TypeError(f'Unsupported data type {type(img)}.  Should be '
                             'Either a np.ndarray, vtkRenderWindow, or vtkImageData')
 
-    im1 = to_img(im1)
-    im2 = to_img(im2)
+    im1 = remove_alpha(to_img(im1))
+    im2 = remove_alpha(to_img(im2))
+
+    if im1.GetDimensions() != im2.GetDimensions():
+        raise RuntimeError('Input images %s and %s are not of equal size.')
 
     if use_vtk:
         img_diff = vtk.vtkImageDifference()
@@ -134,7 +139,5 @@ def compare_images(im1, im2, threshold=1, use_vtk=True):
         return img_diff.GetError()
 
     # otherwise, simply compute the mean pixel difference
-    if im1.shape != im2.shape:
-        raise RuntimeError('Image shapes do not match')
     diff = np.abs(im1.point_arrays[0] - im2.point_arrays[0])
     return np.sum(diff) / im1.point_arrays[0].shape[0]
